==> nativescript-0.2.0-471.tgz: package/lib/common/mobile/app-identifier.js <==
"use strict";
var path = require("path");
var Future = require("fibers/future");
var helpers = require("../helpers");
var util = require("util");

var ANDROID_PROJECT_PATH = "mnt/sdcard/Icenium/";
var ANDROID_NATIVESCRIPT_PROJECT_PATH = "/data/data/";
var ANDROID_CHECK_LIVE_SYNC_INTENT = "com.telerik.IsLiveSyncSupported";
var ANDROID_ION_APP_IDENTIFIER = "com.telerik.AppBuilder";

var NATIVESCRIPT_ION_APP_IDENTIFIER = "com.telerik.NativeScript";

var IOS_PROJECT_PATH = "/Documents/";
var IOS_ION_APP_IDENTIFIER = "com.telerik.Icenium";

var AndroidAppIdentifier = (function () {
    function AndroidAppIdentifier(_appIdentifier) {
        this._appIdentifier = _appIdentifier;
    }
    Object.defineProperty(AndroidAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return this._appIdentifier;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return helpers.fromWindowsRelativePathToUnix(path.join(ANDROID_PROJECT_PATH, this.appIdentifier));
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "";
        },
        enumerable: true,
        configurable: true
    });

    AndroidAppIdentifier.prototype.getliveSyncNotSupportedError = function (device) {
        return util.format("You can't LiveSync on %s! Deploy the app with LiveSync enabled and wait for the initial start up before LiveSyncing.", device.getIdentifier());
    };

    AndroidAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return device.sendBroadcastToDevice(ANDROID_CHECK_LIVE_SYNC_INTENT, { "app-id": this.appIdentifier });
    };
    return AndroidAppIdentifier;
})();
exports.AndroidAppIdentifier = AndroidAppIdentifier;

var AndroidCompanionAppIdentifier = (function () {
    function AndroidCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(AndroidCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return ANDROID_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return helpers.fromWindowsRelativePathToUnix(path.join(ANDROID_PROJECT_PATH, this.appIdentifier));
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "icenium://%s?LiveSyncToken=%s";
        },
        enumerable: true,
        configurable: true
    });

    AndroidCompanionAppIdentifier.prototype.getliveSyncNotSupportedError = function (device) {
        return util.format("Cannot LiveSync changes to the companion app. The companion app is not installed on %s.", device.getIdentifier());
    };

    AndroidCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        var _this = this;
        return (function () {
            var applications = device.getInstalledApplications().wait();
            return _.contains(applications, _this.appIdentifier);
        }).future()();
    };
    return AndroidCompanionAppIdentifier;
})();
exports.AndroidCompanionAppIdentifier = AndroidCompanionAppIdentifier;

var AndroidNativeScriptCompanionAppIdentifier = (function () {
    function AndroidNativeScriptCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(AndroidNativeScriptCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return NATIVESCRIPT_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidNativeScriptCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return helpers.fromWindowsRelativePathToUnix(path.join(ANDROID_NATIVESCRIPT_PROJECT_PATH, this.appIdentifier, "files"));
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidNativeScriptCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "nativescript://%s?LiveSyncToken=%s";
        },
        enumerable: true,
        configurable: true
    });

    AndroidNativeScriptCompanionAppIdentifier.prototype.getliveSyncNotSupportedError = function (device) {
        return util.format("Cannot LiveSync changes to the NativeScript companion app. The NativeScript companion app is not installed on %s.", device.getIdentifier());
    };

    AndroidNativeScriptCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        var _this = this;
        return (function () {
            var applications = device.getInstalledApplications().wait();
            return _.contains(applications, _this.appIdentifier);
        }).future()();
    };
    return AndroidNativeScriptCompanionAppIdentifier;
})();
exports.AndroidNativeScriptCompanionAppIdentifier = AndroidNativeScriptCompanionAppIdentifier;

var IOSAppIdentifier = (function () {
    function IOSAppIdentifier(_appIdentifier) {
        this._appIdentifier = _appIdentifier;
    }
    Object.defineProperty(IOSAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return this._appIdentifier;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return IOS_PROJECT_PATH;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "";
        },
        enumerable: true,
        configurable: true
    });

    IOSAppIdentifier.prototype.getliveSyncNotSupportedError = function (device) {
        return "";
    };

    IOSAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return Future.fromResult(true);
    };
    return IOSAppIdentifier;
})();
exports.IOSAppIdentifier = IOSAppIdentifier;

var IOSCompanionAppIdentifier = (function () {
    function IOSCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(IOSCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return IOS_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return IOS_PROJECT_PATH;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "icenium://%s?LiveSyncToken=%s";
        },
        enumerable: true,
        configurable: true
    });

    IOSCompanionAppIdentifier.prototype.getliveSyncNotSupportedError = function (device) {
        return "";
    };

    IOSCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return Future.fromResult(true);
    };
    return IOSCompanionAppIdentifier;
})();
exports.IOSCompanionAppIdentifier = IOSCompanionAppIdentifier;

var IOSNativeScriptCompanionAppIdentifier = (function () {
    function IOSNativeScriptCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(IOSNativeScriptCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return NATIVESCRIPT_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSNativeScriptCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return IOS_PROJECT_PATH;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSNativeScriptCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "nativescript://%s?LiveSyncToken=%s";
        },
        enumerable: true,
        configurable: true
    });

    IOSNativeScriptCompanionAppIdentifier.prototype.getliveSyncNotSupportedError = function (device) {
        return "";
    };

    IOSNativeScriptCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return Future.fromResult(true);
    };
    return IOSNativeScriptCompanionAppIdentifier;
})();
exports.IOSNativeScriptCompanionAppIdentifier = IOSNativeScriptCompanionAppIdentifier;

var factoryRules = {
    iOS: {
        Cordova: {
            companion: IOSCompanionAppIdentifier,
            vanilla: IOSAppIdentifier
        },
        NativeScript: {
            companion: IOSNativeScriptCompanionAppIdentifier
        }
    },
    Android: {
        Cordova: {
            companion: AndroidCompanionAppIdentifier,
            vanilla: AndroidAppIdentifier
        },
        NativeScript: {
            companion: AndroidNativeScriptCompanionAppIdentifier
        }
    }
};

function createAppIdentifier(platform, appIdentifier, companion, projectType) {
    var projectTypes = $injector.resolve("projectTypes");
    var projectTypeString = projectTypes[projectType];
    var ctor = factoryRules[platform][projectTypeString][companion ? "companion" : "vanilla"];
    return new ctor(appIdentifier);
}
exports.createAppIdentifier = createAppIdentifier;

==> nativescript-0.3.1-18.tgz: package/lib/common/mobile/app-identifier.js <==
"use strict";
var path = require("path");
var Future = require("fibers/future");
var helpers = require("../helpers");
var util = require("util");
var querystring = require("querystring");

var ANDROID_PROJECT_PATH = "mnt/sdcard/Icenium/";
var ANDROID_NATIVESCRIPT_PROJECT_PATH = "/data/data/";
var ANDROID_CHECK_LIVE_SYNC_INTENT = "com.telerik.IsLiveSyncSupported";
var ANDROID_ION_APP_IDENTIFIER = "com.telerik.AppBuilder";

var NATIVESCRIPT_ION_APP_IDENTIFIER = "com.telerik.NativeScript";

var IOS_PROJECT_PATH = "/Documents/";
var IOS_ION_APP_IDENTIFIER = "com.telerik.Icenium";

var AndroidAppIdentifier = (function () {
    function AndroidAppIdentifier(_appIdentifier) {
        this._appIdentifier = _appIdentifier;
    }
    Object.defineProperty(AndroidAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return this._appIdentifier;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return helpers.fromWindowsRelativePathToUnix(path.join(ANDROID_PROJECT_PATH, this.appIdentifier));
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "";
        },
        enumerable: true,
        configurable: true
    });

    AndroidAppIdentifier.prototype.encodeLiveSyncHostUri = function (hostUri) {
        return hostUri;
    };

    AndroidAppIdentifier.prototype.getLiveSyncNotSupportedError = function (device) {
        return util.format("You can't LiveSync on %s! Deploy the app with LiveSync enabled and wait for the initial start up before LiveSyncing.", device.getIdentifier());
    };

    AndroidAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return device.sendBroadcastToDevice(ANDROID_CHECK_LIVE_SYNC_INTENT, { "app-id": this.appIdentifier });
    };
    return AndroidAppIdentifier;
})();
exports.AndroidAppIdentifier = AndroidAppIdentifier;

var AndroidCompanionAppIdentifier = (function () {
    function AndroidCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(AndroidCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return ANDROID_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return helpers.fromWindowsRelativePathToUnix(path.join(ANDROID_PROJECT_PATH, this.appIdentifier));
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "%s/Mist/MobilePackage/redirect?token=%s";
        },
        enumerable: true,
        configurable: true
    });

    AndroidCompanionAppIdentifier.prototype.encodeLiveSyncHostUri = function (hostUri) {
        return hostUri;
    };

    AndroidCompanionAppIdentifier.prototype.getLiveSyncNotSupportedError = function (device) {
        return util.format("Cannot LiveSync changes to the companion app. The companion app is not installed on %s.", device.getIdentifier());
    };

    AndroidCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        var _this = this;
        return (function () {
            var applications = device.getInstalledApplications().wait();
            return _.contains(applications, _this.appIdentifier);
        }).future()();
    };
    return AndroidCompanionAppIdentifier;
})();
exports.AndroidCompanionAppIdentifier = AndroidCompanionAppIdentifier;

var AndroidNativeScriptCompanionAppIdentifier = (function () {
    function AndroidNativeScriptCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(AndroidNativeScriptCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return NATIVESCRIPT_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidNativeScriptCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return helpers.fromWindowsRelativePathToUnix(path.join(ANDROID_NATIVESCRIPT_PROJECT_PATH, this.appIdentifier, "files"));
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(AndroidNativeScriptCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "%s/Mist/MobilePackage/nsredirect?token=%s";
        },
        enumerable: true,
        configurable: true
    });

    AndroidNativeScriptCompanionAppIdentifier.prototype.encodeLiveSyncHostUri = function (hostUri) {
        return hostUri;
    };

    AndroidNativeScriptCompanionAppIdentifier.prototype.getLiveSyncNotSupportedError = function (device) {
        return util.format("Cannot LiveSync changes to the NativeScript companion app. The NativeScript companion app is not installed on %s.", device.getIdentifier());
    };

    AndroidNativeScriptCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        var _this = this;
        return (function () {
            var applications = device.getInstalledApplications().wait();
            return _.contains(applications, _this.appIdentifier);
        }).future()();
    };
    return AndroidNativeScriptCompanionAppIdentifier;
})();
exports.AndroidNativeScriptCompanionAppIdentifier = AndroidNativeScriptCompanionAppIdentifier;

var IOSAppIdentifier = (function () {
    function IOSAppIdentifier(_appIdentifier) {
        this._appIdentifier = _appIdentifier;
    }
    Object.defineProperty(IOSAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return this._appIdentifier;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return IOS_PROJECT_PATH;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "";
        },
        enumerable: true,
        configurable: true
    });

    IOSAppIdentifier.prototype.encodeLiveSyncHostUri = function (hostUri) {
        return querystring.escape(hostUri);
    };

    IOSAppIdentifier.prototype.getLiveSyncNotSupportedError = function (device) {
        return "";
    };

    IOSAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return Future.fromResult(true);
    };
    return IOSAppIdentifier;
})();
exports.IOSAppIdentifier = IOSAppIdentifier;

var IOSCompanionAppIdentifier = (function () {
    function IOSCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(IOSCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return IOS_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return IOS_PROJECT_PATH;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "icenium://%s?LiveSyncToken=%s";
        },
        enumerable: true,
        configurable: true
    });

    IOSCompanionAppIdentifier.prototype.encodeLiveSyncHostUri = function (hostUri) {
        return querystring.escape(hostUri);
    };

    IOSCompanionAppIdentifier.prototype.getLiveSyncNotSupportedError = function (device) {
        return "";
    };

    IOSCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return Future.fromResult(true);
    };
    return IOSCompanionAppIdentifier;
})();
exports.IOSCompanionAppIdentifier = IOSCompanionAppIdentifier;

var IOSNativeScriptCompanionAppIdentifier = (function () {
    function IOSNativeScriptCompanionAppIdentifier(servedApp) {
        this.servedApp = servedApp;
    }
    Object.defineProperty(IOSNativeScriptCompanionAppIdentifier.prototype, "appIdentifier", {
        get: function () {
            return NATIVESCRIPT_ION_APP_IDENTIFIER;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSNativeScriptCompanionAppIdentifier.prototype, "deviceProjectPath", {
        get: function () {
            return IOS_PROJECT_PATH;
        },
        enumerable: true,
        configurable: true
    });

    Object.defineProperty(IOSNativeScriptCompanionAppIdentifier.prototype, "liveSyncFormat", {
        get: function () {
            return "nativescript://%s?LiveSyncToken=%s";
        },
        enumerable: true,
        configurable: true
    });

    IOSNativeScriptCompanionAppIdentifier.prototype.encodeLiveSyncHostUri = function (hostUri) {
        return querystring.escape(hostUri);
    };

    IOSNativeScriptCompanionAppIdentifier.prototype.getLiveSyncNotSupportedError = function (device) {
        return "";
    };

    IOSNativeScriptCompanionAppIdentifier.prototype.isLiveSyncSupported = function (device) {
        return Future.fromResult(true);
    };
    return IOSNativeScriptCompanionAppIdentifier;
})();
exports.IOSNativeScriptCompanionAppIdentifier = IOSNativeScriptCompanionAppIdentifier;

var factoryRules = {
    iOS: {
        Cordova: {
            companion: IOSCompanionAppIdentifier,
            vanilla: IOSAppIdentifier
        },
        NativeScript: {
            companion: IOSNativeScriptCompanionAppIdentifier
        }
    },
    Android: {
        Cordova: {
            companion: AndroidCompanionAppIdentifier,
            vanilla: AndroidAppIdentifier
        },
        NativeScript: {
            companion: AndroidNativeScriptCompanionAppIdentifier
        }
    }
};

function createAppIdentifier(platform, appIdentifier, companion, projectType) {
    var projectTypes = $injector.resolve("projectTypes");
    var projectTypeString = projectTypes[projectType];
    var ctor = factoryRules[platform][projectTypeString][companion ? "companion" : "vanilla"];
    return new ctor(appIdentifier);
}
exports.createAppIdentifier = createAppIdentifier;
